import { AbstractRepository } from '@crosslab/service-common';
import { templateUrlFromId } from '../../methods/url.js';
import { TemplateModel } from '../model.js';
export class TemplateRepository extends AbstractRepository {
    dependencies = {};
    constructor() {
        super('Template');
    }
    dependenciesMet() {
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(TemplateModel);
    }
    async create(data) {
        const model = await super.create();
        model.configuration = {
            devices: [],
            roles: [],
            serviceConfigurations: [],
        };
        if (data)
            await this.write(model, data);
        return model;
    }
    async write(model, data) {
        if (data.name)
            model.name = data.name;
        if (data.description !== undefined)
            model.description = data.description;
        if (data.configuration?.devices)
            model.configuration.devices = data.configuration.devices;
        if (data.configuration?.roles)
            model.configuration.roles = data.configuration.roles;
        if (data.configuration?.serviceConfigurations)
            model.configuration.serviceConfigurations =
                data.configuration.serviceConfigurations;
    }
    async format(model) {
        return {
            ...(await this.formatOverview(model)),
            configuration: model.configuration,
        };
    }
    async formatOverview(model) {
        return {
            url: templateUrlFromId(model.uuid),
            name: model.name,
            description: model.description,
        };
    }
}
//# sourceMappingURL=template.js.map